"""
@File       console_colors.py
@Brief      Colors
@Author     cavacagu
@Date       13-05-2019
@copyright  Microsoft Corporation. All rights reserved.
"""

#pylint: disable = too-few-public-methods
class ConsoleColors:
    """Console colors associated with various logging levels"""
    OK = '\033[92m'
    VERBOSE = '\033[36m'
    INFO = '\033[94m'
    ERROR = '\033[91m'
    WARNING = '\033[93m'
    END = '\033[0m'
#pylint: enable = too-few-public-methods



"""
@File       utils.py
@Brief      Utils methods
@Author     cavacagu
@Date       12-02-2019
@copyright  Microsoft Corporation. All rights reserved.
"""
from . import console_colors

def print_success_message(message: str) -> None:
    """Prints a message in success format
    PARAMS:
    - message: Message to print
    """
    print(console_colors.ConsoleColors.OK + message + console_colors.ConsoleColors.END)

def print_error_message(message: str) -> None:
    """Prints a message in error format
    PARAMS:
    - message: Message to print
    """
    print(console_colors.ConsoleColors.ERROR + message + console_colors.ConsoleColors.END)

def print_warning_message(message: str) -> None:
    """Prints a message in error format
    PARAMS:
    - message: Message to print
    """
    print(console_colors.ConsoleColors.WARNING + message + console_colors.ConsoleColors.END)

def print_info_message(message: str) -> None:
    """Prints a message in info format
    PARAMS:
    - message: Message to print
    """
    print(console_colors.ConsoleColors.INFO + message + console_colors.ConsoleColors.END)
